@@ -130,6 +130,8 @@ private Q_SLOTS:
     void cancelCopyAndCleanDest();
     void cancelCopyAndCleanDest_data();
 
+    void renameFileWithNoUDSACCESS();
+
     // Remote tests
     // void copyFileToSystem();
 
@@ -147,7 +149,9 @@ protected Q_SLOTS:
 
 private:
     void enterLoop();
-    enum { AlreadyExists = 1 };
+    enum {
+        AlreadyExists = 1
+    };
     void copyLocalFile(const QString &src, const QString &dest);
     bool checkXattrFsSupport(const QString &writeTest);
     bool setXattr(const QString &src);
