@@ -26,6 +26,8 @@
 #include <QDirIterator>
 #include <QLocale>
 #include <QMimeDatabase>
+#include <QRegularExpression>
+#include <QTimeZone>
 
 #include <KConfigGroup>
 #include <KDesktopFile>
@@ -591,6 +593,8 @@ void KFileItemPrivate::determineMimeTypeHelper(const QUrl &url) const
         const QString scheme = url.scheme();
         if (scheme.startsWith(QLatin1String("http")) || scheme == QLatin1String("mailto")) {
             m_mimeType = db.mimeTypeForName(QLatin1String("application/octet-stream"));
+        } else if (url.path().isEmpty()) {
+            m_mimeType = db.mimeTypeForName(QLatin1String("inode/directory"));
         } else {
             m_mimeType = db.mimeTypeForFile(url.path(), QMimeDatabase::MatchMode::MatchExtension);
         }
@@ -1062,9 +1066,10 @@ QString KFileItem::mimeComment() const
     // the MIME type to be determined, which is done here, and possibly delayed...
     if (isLocalUrl && !d->isSlow() && mime.inherits(QStringLiteral("application/x-desktop"))) {
         KDesktopFile cfg(url.toLocalFile());
-        QString comment = cfg.desktopGroup().readEntry("Comment");
-        if (!comment.isEmpty()) {
-            return comment;
+
+        // Display "Link" instead of the destination mime
+        if (cfg.hasLinkType()) {
+            return QStringLiteral("Link");
         }
     }
 
@@ -1582,7 +1587,24 @@ QString KFileItem::timeString(FileTimes which) const
         return QString();
     }
 
-    return QLocale::system().toString(d->time(which), QLocale::LongFormat);
+    const QDateTime dt = d->time(which);
+    if (!dt.isValid()) {
+        return QString();
+    }
+
+    QString format = QLocale::system().dateTimeFormat(QLocale::LongFormat);
+
+    // QLocale::LongFormat annyoingly include the full time zone name.
+    // Only display the time zone when it is different from the current one
+    // and also replace it by the abbreviation.
+    static QRegularExpression s_timeZoneRegExp(QStringLiteral(R"((\stttt$))"));
+    if (dt.timeZone() != QTimeZone::systemTimeZone()) {
+        format.replace(s_timeZoneRegExp, QLatin1StringView("t"));
+    } else {
+        format.remove(s_timeZoneRegExp);
+    }
+
+    return QLocale::system().toString(dt, format);
 }
 
 QUrl KFileItem::mostLocalUrl(bool *local) const
