@@ -148,7 +148,7 @@ void FilePreviewJob::statFile()
     statJob->start();
 }
 
-void FilePreviewJob::preparePluginForMimetype(const QString &mimeType)
+bool FilePreviewJob::preparePluginForMimetype(const QString &mimeType)
 {
     auto setUpCaching = [this]() {
         short cacheSize = 0;
@@ -227,11 +227,10 @@ void FilePreviewJob::preparePluginForMimetype(const QString &mimeType)
 
         if (!plugin.isValid()) {
             qCDebug(KIO_GUI) << "Plugin for item " << m_item.item << " is not valid. Emitting result.";
-            emitResult();
-            return;
+            return false;
         }
 
-        m_standardThumbnailer = plugin.description() == QStringLiteral("standardthumbnailer");
+        m_standardThumbnailer = plugin.category() == QStringLiteral("standardthumbnailer");
         m_plugin = plugin;
         m_thumbnailWorkerMetaData.insert(QStringLiteral("handlesSequences"), QString::number(m_plugin.value(QStringLiteral("HandleSequences"), false)));
 
@@ -241,10 +240,10 @@ void FilePreviewJob::preparePluginForMimetype(const QString &mimeType)
                 setUpCaching();
             }
         }
+        return true;
     } else {
         qCDebug(KIO_GUI) << "Could not get plugin for, " << m_item.item << " - emitting result.";
-        emitResult();
-        return;
+        return false;
     }
 }
 
@@ -263,10 +262,14 @@ void FilePreviewJob::slotStatFile(KJob *job)
     m_currentDeviceId = statResult.numberValue(KIO::UDSEntry::UDS_DEVICE_ID, 0);
     m_tOrig = QDateTime::fromSecsSinceEpoch(statResult.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME, 0));
 
-    if (m_item.item.isMimeTypeKnown()) {
-        preparePluginForMimetype(m_item.item.mimetype());
-    } else {
-        preparePluginForMimetype(statResult.stringValue(KIO::UDSEntry::UDS_MIME_TYPE));
+    // If we stat'd the file already, might as well report it back.
+    if (!statResult.stringValue(KIO::UDSEntry::UDS_MIME_TYPE).isEmpty()) {
+        m_item.item = KFileItem(statResult, m_item.item.url());
+    }
+
+    if (!preparePluginForMimetype(m_item.item.mimetype())) {
+        emitResult();
+        return;
     }
 
     if (isLocal) {
@@ -759,14 +762,14 @@ QList<KPluginMetaData> FilePreviewJob::standardThumbnailers()
             kplugin[QStringLiteral("Id")] = QFileInfo(thumbnailerPath).completeBaseName();
             kplugin[QStringLiteral("MimeTypes")] = QJsonArray::fromStringList(mimetypes);
             kplugin[QStringLiteral("Name")] = name;
-            kplugin[QStringLiteral("Description")] = QStringLiteral("standardthumbnailer");
+            kplugin[QStringLiteral("Category")] = QStringLiteral("standardthumbnailer");
 
             QJsonObject root;
             root[QStringLiteral("CacheThumbnail")] = true;
             root[QStringLiteral("Exec")] = exec;
             root[QStringLiteral("KPlugin")] = kplugin;
 
-            KPluginMetaData standardThumbnailerPlugin(root, QString());
+            KPluginMetaData standardThumbnailerPlugin(root, thumbnailerPath);
             standardThumbs.append(standardThumbnailerPlugin);
         }
     }
