@@ -12,12 +12,14 @@
 class SearchProvider : public KUriFilterSearchProvider
 {
 public:
-    SearchProvider() : m_dirty(false), m_isHidden(false)
+    SearchProvider()
+        : m_dirty(false)
+        , m_isHidden(false)
     {
     }
 
     explicit SearchProvider(const QString &servicePath);
-    ~SearchProvider();
+    ~SearchProvider() override;
 
     const QString &charset() const
     {
@@ -34,7 +36,8 @@ public:
         return m_dirty;
     }
 
-    bool isHidden() const {
+    bool isHidden() const
+    {
         return m_isHidden;
     }
 
