@@ -117,11 +117,6 @@ public:
         if (showProgressInfo) {
             KIO::getJobTracker()->registerJob(this);
         }
-
-        d_ptr->m_privilegeExecutionEnabled = true;
-        d_ptr->m_operationType = d_ptr->Other;
-        d_ptr->m_title = i18n("Undo Changes");
-        d_ptr->m_message = i18n("Undoing this operation requires root privileges. Do you want to continue?");
     }
 
     ~UndoJob() override = default;
