@@ -27,6 +27,7 @@
 #include <QScrollBar>
 #include <QToolButton>
 
+#include <KContextualHelpButton>
 #include <KFileUtils>
 #include <KGuiItem>
 #include <KIconLoader>
@@ -368,6 +369,7 @@ RenameDialog::RenameDialog(QWidget *parent,
                             KShell::tildeCollapse(d->dest.toDisplayString(QUrl::PreferLocalFile)));
         }
         auto *questionLabel = new QLabel(question, this);
+        questionLabel->setWordWrap(true);
         questionLabel->setAlignment(Qt::AlignHCenter);
         gridLayout->addWidget(questionLabel, gridRow, 0, 1, 4); // takes the complete first line
 
@@ -442,15 +444,13 @@ RenameDialog::RenameDialog(QWidget *parent,
             }
             QLabel *filesIdenticalLabel = createLabel(this, text);
             if (CompareFilesResult == CompareFilesResult::PartiallyIdentical) {
-                auto *pixmapLabel = new QLabel(this);
-                pixmapLabel->setPixmap(QIcon::fromTheme(QStringLiteral("help-about")).pixmap(QSize(16, 16)));
-                pixmapLabel->setToolTip(
+                auto *helpLabel = new KContextualHelpButton(this);
+                helpLabel->setContextualHelpText(
                     i18n("The files are likely to be identical: they have the same size and their contents are the same at the beginning, middle and end."));
-                pixmapLabel->setCursor(Qt::WhatsThisCursor);
 
                 auto *hbox = new QHBoxLayout();
                 hbox->addWidget(filesIdenticalLabel);
-                hbox->addWidget(pixmapLabel);
+                hbox->addWidget(helpLabel);
                 hbox_verdicts->addLayout(hbox);
             } else {
                 hbox_verdicts->addWidget(filesIdenticalLabel);
@@ -747,9 +747,11 @@ void RenameDialog::resizePanels()
     d->m_destDateLabel->setMinimumWidth(minDateWidth);
 
     KIO::PreviewJob *srcJob = KIO::filePreview(KFileItemList{d->srcItem}, QSize(d->m_srcPreview->width() * qreal(0.9), d->m_srcPreview->height()));
+    srcJob->setDevicePixelRatio(devicePixelRatioF());
     srcJob->setScaleType(KIO::PreviewJob::Unscaled);
 
     KIO::PreviewJob *destJob = KIO::filePreview(KFileItemList{d->destItem}, QSize(d->m_destPreview->width() * qreal(0.9), d->m_destPreview->height()));
+    destJob->setDevicePixelRatio(devicePixelRatioF());
     destJob->setScaleType(KIO::PreviewJob::Unscaled);
 
     connect(srcJob, &PreviewJob::gotPreview, this, &RenameDialog::showSrcPreview);
