@@ -14,7 +14,6 @@
 #include <kio/listjob.h>
 #include <kio/mimetypejob.h>
 #include <kio/mkdirjob.h>
-#include <kio/simplejob.h>
 #include <kio/statjob.h>
 #include <kio/transferjob.h>
 #include <kprotocolinfo.h>
@@ -42,7 +41,7 @@
 using namespace KIO;
 
 KioWorkerTest::KioWorkerTest(QString src, QString dest, uint op, uint pr)
-    : KMainWindow(nullptr)
+    : QMainWindow(nullptr)
 {
     job = nullptr;
 
@@ -76,7 +75,7 @@ KioWorkerTest::KioWorkerTest(QString src, QString dest, uint op, uint pr)
     opButtons = new QButtonGroup(main_widget);
     QGroupBox *box = new QGroupBox(QStringLiteral("Operation"), main_widget);
     topLayout->addWidget(box, 10);
-    connect(opButtons, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked), this, &KioWorkerTest::changeOperation);
+    connect(opButtons, &QButtonGroup::buttonClicked, this, &KioWorkerTest::changeOperation);
 
     QBoxLayout *hbLayout = new QHBoxLayout(box);
 
@@ -128,7 +127,7 @@ KioWorkerTest::KioWorkerTest(QString src, QString dest, uint op, uint pr)
     progressButtons = new QButtonGroup(main_widget);
     box = new QGroupBox(QStringLiteral("Progress dialog mode"), main_widget);
     topLayout->addWidget(box, 10);
-    connect(progressButtons, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked), this, &KioWorkerTest::changeProgressMode);
+    connect(progressButtons, &QButtonGroup::buttonClicked, this, &KioWorkerTest::changeProgressMode);
 
     hbLayout = new QHBoxLayout(box);
 
@@ -246,7 +245,7 @@ void KioWorkerTest::startJob()
     }
 
     case Stat:
-        job = KIO::statDetails(src, KIO::StatJob::SourceSide);
+        job = KIO::stat(src);
         break;
 
     case Get: {
@@ -325,7 +324,7 @@ void KioWorkerTest::printUDSEntry(const KIO::UDSEntry &entry)
 
     QDateTime timestamp;
 
-    const QVector<uint> keys = entry.fields();
+    const QList<uint> keys = entry.fields();
     for (auto it = keys.cbegin(); it != keys.cend(); ++it) {
         switch (*it) {
         case KIO::UDSEntry::UDS_FILE_TYPE: {
@@ -348,6 +347,12 @@ void KioWorkerTest::printUDSEntry(const KIO::UDSEntry &entry)
         case KIO::UDSEntry::UDS_GROUP:
             qDebug() << "Group : " << (entry.stringValue(*it));
             break;
+        case KIO::UDSEntry::UDS_LOCAL_USER_ID:
+            qDebug() << "User id : " << (entry.numberValue(*it));
+            break;
+        case KIO::UDSEntry::UDS_LOCAL_GROUP_ID:
+            qDebug() << "Group id : " << (entry.numberValue(*it));
+            break;
         case KIO::UDSEntry::UDS_NAME:
             qDebug() << "Name : " << (entry.stringValue(*it));
             // m_strText = decodeFileName( it.value().toString() );
@@ -391,8 +396,8 @@ void KioWorkerTest::slotEntries(KIO::Job *job, const KIO::UDSEntryList &list)
         qDebug() << name;
 
         KProtocolInfo::ExtraFieldList::Iterator extraFieldsIt = extraFields.begin();
-        const QVector<uint> fields = it->fields();
-        QVector<uint>::ConstIterator it2 = fields.begin();
+        const QList<uint> fields = it->fields();
+        QList<uint>::ConstIterator it2 = fields.begin();
         for (; it2 != fields.end(); it2++) {
             if (*it2 >= UDSEntry::UDS_EXTRA && *it2 <= UDSEntry::UDS_EXTRA_END) {
                 if (extraFieldsIt != extraFields.end()) {
@@ -413,7 +418,7 @@ void KioWorkerTest::slotData(KIO::Job *, const QByteArray &data)
     if (data.size() == 0) {
         qDebug() << "Data: <End>";
     } else {
-        qDebug() << "Data: \"" << QString(data) << "\"";
+        qDebug() << "Data: \"" << QString::fromUtf8(data) << "\"";
     }
 }
 
@@ -464,7 +469,7 @@ int main(int argc, char **argv)
     const char version[] = "v0.0.0 0000"; // :-)
 
     QApplication app(argc, argv);
-    app.setApplicationVersion(version);
+    app.setApplicationVersion(QString::fromLatin1(version));
 
     uint op = KioWorkerTest::Copy;
     uint pr = 0;
@@ -536,7 +541,7 @@ int main(int argc, char **argv)
     test->show();
     test->resize(test->sizeHint());
 
-    app.exec();
+    return app.exec();
 }
 
 #include "moc_kioworkertest.cpp"
